pub struct Description {
pub purpose: Cow<'static, str>,
pub usage: Cow<'static, str>,
pub examples: Vec<Example>,
}Expand description
A comprehensive description of a command. May include examples.
Fields
purpose: Cow<'static, str>Why the command exists. One (or more) fully punctuated sentences.
usage: Cow<'static, str>Syntax for arguments, if any. Leave blank if the command does not accept arguments. (Do not include the name of the command.)
examples: Vec<Example>Zero or more examples. Should be empty if the command does not take arguments, in which case the example is implied.