pub struct InvalidCommandParserSpec(/* private fields */);Expand description
Raised by Commander if there was something wrong with the parsers given to it. Perhaps
the parsers were incorrectly specified or conflicted amongst themselves.